@@ -1,4 +1,5 @@
 #include <sys/stat.h>
+#include <sys/types.h>
 
 #include <err.h>
 #include <errno.h>
@@ -223,7 +224,7 @@ efopen(const char *name, const char *flags)
 	FILE *fp;
 
 	if (!(fp = fopen(name, flags)))
-		err(1, "fopen");
+		err(1, "fopen: '%s'", name);
 
 	return fp;
 }
@@ -995,6 +996,7 @@ main(int argc, char *argv[])
 	git_object *obj = NULL;
 	const git_oid *head = NULL;
 	const git_error *e = NULL;
+	mode_t mask;
 	FILE *fp, *fpread;
 	char path[PATH_MAX], repodirabs[PATH_MAX + 1], *p;
 	char tmppath[64] = "cache.XXXXXXXXXXXX", buf[BUFSIZ];
@@ -1094,7 +1096,7 @@ main(int argc, char *argv[])
 	/* log for HEAD */
 	fp = efopen("log.html", "w");
 	relpath = "";
-	mkdir("commit", 0755);
+	mkdir("commit", S_IRWXU | S_IRWXG | S_IRWXO);
 	writeheader(fp, "Log");
 	fputs("<table id=\"log\"><thead>\n<tr><td><b>Date</b></td>"
 	      "<td><b>Commit message</b></td>"
@@ -1115,7 +1117,7 @@ main(int argc, char *argv[])
 		if ((fd = mkstemp(tmppath)) == -1)
 			err(1, "mkstemp");
 		if (!(wcachefp = fdopen(fd, "w")))
-			err(1, "fdopen");
+			err(1, "fdopen: '%s'", tmppath);
 		/* write last commit id (HEAD) */
 		git_oid_tostr(buf, sizeof(buf), head);
 		fprintf(wcachefp, "%s\n", buf);
@@ -1165,8 +1167,14 @@ main(int argc, char *argv[])
 	fclose(fp);
 
 	/* rename new cache file on success */
-	if (cachefile && rename(tmppath, cachefile))
-		err(1, "rename: '%s' to '%s'", tmppath, cachefile);
+	if (cachefile) {
+		if (rename(tmppath, cachefile))
+			err(1, "rename: '%s' to '%s'", tmppath, cachefile);
+		umask((mask = umask(0)));
+		if (chmod(cachefile,
+		    (S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH) & ~mask))
+			err(1, "chmod: '%s'", cachefile);
+	}
 
 	/* cleanup */
 	git_repository_free(repo);
